Index: content/browser/loader/upload_data_stream_builder.h |
diff --git a/content/browser/loader/upload_data_stream_builder.h b/content/browser/loader/upload_data_stream_builder.h |
index 9b2bfcbf275d03d0aac77461228505bd71a42666..fae5f3a70cafde9a3bd9d857fd374f12b45e36c2 100644 |
--- a/content/browser/loader/upload_data_stream_builder.h |
+++ b/content/browser/loader/upload_data_stream_builder.h |
@@ -27,7 +27,7 @@ class BlobStorageContext; |
namespace content { |
-class ResourceRequestBodyImpl; |
+class ResourceRequestBody; |
class CONTENT_EXPORT UploadDataStreamBuilder { |
public: |
@@ -35,14 +35,14 @@ class CONTENT_EXPORT UploadDataStreamBuilder { |
// |
// If |body| contains any blob references, the caller is responsible for |
// making sure them outlive the returned value of UploadDataStream. We do this |
// by binding the BlobDataHandles of them to ResourceRequestBodyImpl in |
// ResourceDispatcherHostImpl::BeginRequest(). |
// |
// |file_system_context| is used to create a FileStreamReader for files with |
// filesystem URLs. |file_task_runner| is used to perform file operations |
// when the data gets uploaded. |
static std::unique_ptr<net::UploadDataStream> Build( |
- ResourceRequestBodyImpl* body, |
+ ResourceRequestBody* body, |
storage::BlobStorageContext* blob_context, |
storage::FileSystemContext* file_system_context, |
base::SingleThreadTaskRunner* file_task_runner); |
@@ -35,14 +35,14 @@ class CONTENT_EXPORT UploadDataStreamBuilder { |
// If |body| contains any blob references, the caller is responsible for |
// making sure them outlive the returned value of UploadDataStream. We do this |
- // by binding the BlobDataHandles of them to ResourceRequestBodyImpl in |
+ // by binding the BlobDataHandles of them to ResourceRequestBody in |
// ResourceDispatcherHostImpl::BeginRequest(). |
// |